==> ejc-sale-impl-3.0.0-20220404.055637-20-sources.jar: com/ejianc/business/sale/vo/SalesorderdetilsVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 销售单子表信息
 * 
 * @author generator
 * 
 */
public class SalesorderdetilsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long salesorderId; // 主表主键
    private Long sort; // 序号
    private String productName; // 产品名称
    private String specName; // 规格
    private BigDecimal unitPrice; // 单价
    private Long salesVolume; // 销售数量
    private BigDecimal salesAmount; // 销售金额
    private Long productionQuantity; // 生产数量
    private BigDecimal productionAmount; // 生产金额
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String stoneName; // 石料
    private String asphaltName; // 沥青
    private Long categoryId1; // 分类id1
    private String categoryName1; // 材料分类名称1
    private Long varietiesId1; // 品种id1
    private String varietiesName1; // 品种名称1
    private BigDecimal thousandRate1; // 千分比1
    private Long categoryId2; // 分类id2
    private String categoryName2; // 材料分类名称2
    private Long varietiesId2; // 品种id2
    private String varietiesName2; // 品种名称2
    private BigDecimal thousandRate2; // 千分比2
    private Long categoryId3; // 分类id3
    private String categoryName3; // 材料分类名称3
    private Long varietiesId3; // 品种id3
    private String varietiesName3; // 品种名称3
    private BigDecimal thousandRate3; // 千分比3
    private Long productId; // 产品id
    

    public Long getSalesorderId() {
        return salesorderId;
    }

    public void setSalesorderId(Long salesorderId) {
        this.salesorderId = salesorderId;
    }
    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpecName() {
        return specName;
    }

    public void setSpecName(String specName) {
        this.specName = specName;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public Long getSalesVolume() {
        return salesVolume;
    }

    public void setSalesVolume(Long salesVolume) {
        this.salesVolume = salesVolume;
    }
    public BigDecimal getSalesAmount() {
        return salesAmount;
    }

    public void setSalesAmount(BigDecimal salesAmount) {
        this.salesAmount = salesAmount;
    }
    public Long getProductionQuantity() {
        return productionQuantity;
    }

    public void setProductionQuantity(Long productionQuantity) {
        this.productionQuantity = productionQuantity;
    }
    public BigDecimal getProductionAmount() {
        return productionAmount;
    }

    public void setProductionAmount(BigDecimal productionAmount) {
        this.productionAmount = productionAmount;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getStoneName() {
        return stoneName;
    }

    public void setStoneName(String stoneName) {
        this.stoneName = stoneName;
    }
    public String getAsphaltName() {
        return asphaltName;
    }

    public void setAsphaltName(String asphaltName) {
        this.asphaltName = asphaltName;
    }
    @ReferSerialTransfer(referCode="MaterialRef")
    public Long getCategoryId1() {
        return categoryId1;
    }

    @ReferDeserialTransfer
    public void setCategoryId1(Long categoryId1) {
        this.categoryId1 = categoryId1;
    }
    public String getCategoryName1() {
        return categoryName1;
    }

    public void setCategoryName1(String categoryName1) {
        this.categoryName1 = categoryName1;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId1() {
        return varietiesId1;
    }

    @ReferDeserialTransfer
    public void setVarietiesId1(Long varietiesId1) {
        this.varietiesId1 = varietiesId1;
    }
    public String getVarietiesName1() {
        return varietiesName1;
    }

    public void setVarietiesName1(String varietiesName1) {
        this.varietiesName1 = varietiesName1;
    }
    public BigDecimal getThousandRate1() {
        return thousandRate1;
    }

    public void setThousandRate1(BigDecimal thousandRate1) {
        this.thousandRate1 = thousandRate1;
    }
    @ReferSerialTransfer(referCode="MaterialRef")
    public Long getCategoryId2() {
        return categoryId2;
    }

    @ReferDeserialTransfer
    public void setCategoryId2(Long categoryId2) {
        this.categoryId2 = categoryId2;
    }
    public String getCategoryName2() {
        return categoryName2;
    }

    public void setCategoryName2(String categoryName2) {
        this.categoryName2 = categoryName2;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId2() {
        return varietiesId2;
    }

    @ReferDeserialTransfer
    public void setVarietiesId2(Long varietiesId2) {
        this.varietiesId2 = varietiesId2;
    }
    public String getVarietiesName2() {
        return varietiesName2;
    }

    public void setVarietiesName2(String varietiesName2) {
        this.varietiesName2 = varietiesName2;
    }
    public BigDecimal getThousandRate2() {
        return thousandRate2;
    }

    public void setThousandRate2(BigDecimal thousandRate2) {
        this.thousandRate2 = thousandRate2;
    }
    @ReferSerialTransfer(referCode="MaterialRef")
    public Long getCategoryId3() {
        return categoryId3;
    }

    @ReferDeserialTransfer
    public void setCategoryId3(Long categoryId3) {
        this.categoryId3 = categoryId3;
    }
    public String getCategoryName3() {
        return categoryName3;
    }

    public void setCategoryName3(String categoryName3) {
        this.categoryName3 = categoryName3;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId3() {
        return varietiesId3;
    }

    @ReferDeserialTransfer
    public void setVarietiesId3(Long varietiesId3) {
        this.varietiesId3 = varietiesId3;
    }
    public String getVarietiesName3() {
        return varietiesName3;
    }

    public void setVarietiesName3(String varietiesName3) {
        this.varietiesName3 = varietiesName3;
    }
    public BigDecimal getThousandRate3() {
        return thousandRate3;
    }

    public void setThousandRate3(BigDecimal thousandRate3) {
        this.thousandRate3 = thousandRate3;
    }
    @ReferSerialTransfer(referCode="ProductRef")
    public Long getProductId() {
        return productId;
    }

    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }
    
}

==> ejc-sale-impl-3.0.0-20220419.090228-47-sources.jar: com/ejianc/business/sale/vo/SalesorderdetilsVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 销售单子表信息
 * 
 * @author generator
 * 
 */
public class SalesorderdetilsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long salesorderId; // 主表主键
    private Long sort; // 序号
    private String productName; // 产品名称
    private String specName; // 规格
    private BigDecimal unitPrice; // 单价
    private BigDecimal salesVolume; // 销售数量
    private BigDecimal salesAmount; // 销售金额
    private BigDecimal productionQuantity; // 生产数量
    private BigDecimal productionAmount; // 生产金额
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String stoneName; // 石料
    private String asphaltName; // 沥青
    private Long categoryId1; // 分类id1
    private String categoryName1; // 材料分类名称1
    private Long varietiesId1; // 品种id1
    private String varietiesName1; // 品种名称1
    private BigDecimal thousandRate1; // 千分比1
    private Long categoryId2; // 分类id2
    private String categoryName2; // 材料分类名称2
    private Long varietiesId2; // 品种id2
    private String varietiesName2; // 品种名称2
    private BigDecimal thousandRate2; // 千分比2
    private Long categoryId3; // 分类id3
    private String categoryName3; // 材料分类名称3
    private Long varietiesId3; // 品种id3
    private String varietiesName3; // 品种名称3
    private BigDecimal thousandRate3; // 千分比3
    private Long productId; // 产品id
    

    public Long getSalesorderId() {
        return salesorderId;
    }

    public void setSalesorderId(Long salesorderId) {
        this.salesorderId = salesorderId;
    }
    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpecName() {
        return specName;
    }

    public void setSpecName(String specName) {
        this.specName = specName;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getSalesVolume() {
        return salesVolume;
    }

    public void setSalesVolume(BigDecimal salesVolume) {
        this.salesVolume = salesVolume;
    }
    public BigDecimal getSalesAmount() {
        return salesAmount;
    }

    public void setSalesAmount(BigDecimal salesAmount) {
        this.salesAmount = salesAmount;
    }
    public BigDecimal getProductionQuantity() {
        return productionQuantity;
    }

    public void setProductionQuantity(BigDecimal productionQuantity) {
        this.productionQuantity = productionQuantity;
    }
    public BigDecimal getProductionAmount() {
        return productionAmount;
    }

    public void setProductionAmount(BigDecimal productionAmount) {
        this.productionAmount = productionAmount;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getStoneName() {
        return stoneName;
    }

    public void setStoneName(String stoneName) {
        this.stoneName = stoneName;
    }
    public String getAsphaltName() {
        return asphaltName;
    }

    public void setAsphaltName(String asphaltName) {
        this.asphaltName = asphaltName;
    }
    @ReferSerialTransfer(referCode="MaterialRef")
    public Long getCategoryId1() {
        return categoryId1;
    }

    @ReferDeserialTransfer
    public void setCategoryId1(Long categoryId1) {
        this.categoryId1 = categoryId1;
    }
    public String getCategoryName1() {
        return categoryName1;
    }

    public void setCategoryName1(String categoryName1) {
        this.categoryName1 = categoryName1;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId1() {
        return varietiesId1;
    }

    @ReferDeserialTransfer
    public void setVarietiesId1(Long varietiesId1) {
        this.varietiesId1 = varietiesId1;
    }
    public String getVarietiesName1() {
        return varietiesName1;
    }

    public void setVarietiesName1(String varietiesName1) {
        this.varietiesName1 = varietiesName1;
    }
    public BigDecimal getThousandRate1() {
        return thousandRate1;
    }

    public void setThousandRate1(BigDecimal thousandRate1) {
        this.thousandRate1 = thousandRate1;
    }
    @ReferSerialTransfer(referCode="MaterialRef")
    public Long getCategoryId2() {
        return categoryId2;
    }

    @ReferDeserialTransfer
    public void setCategoryId2(Long categoryId2) {
        this.categoryId2 = categoryId2;
    }
    public String getCategoryName2() {
        return categoryName2;
    }

    public void setCategoryName2(String categoryName2) {
        this.categoryName2 = categoryName2;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId2() {
        return varietiesId2;
    }

    @ReferDeserialTransfer
    public void setVarietiesId2(Long varietiesId2) {
        this.varietiesId2 = varietiesId2;
    }
    public String getVarietiesName2() {
        return varietiesName2;
    }

    public void setVarietiesName2(String varietiesName2) {
        this.varietiesName2 = varietiesName2;
    }
    public BigDecimal getThousandRate2() {
        return thousandRate2;
    }

    public void setThousandRate2(BigDecimal thousandRate2) {
        this.thousandRate2 = thousandRate2;
    }
    @ReferSerialTransfer(referCode="MaterialRef")
    public Long getCategoryId3() {
        return categoryId3;
    }

    @ReferDeserialTransfer
    public void setCategoryId3(Long categoryId3) {
        this.categoryId3 = categoryId3;
    }
    public String getCategoryName3() {
        return categoryName3;
    }

    public void setCategoryName3(String categoryName3) {
        this.categoryName3 = categoryName3;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId3() {
        return varietiesId3;
    }

    @ReferDeserialTransfer
    public void setVarietiesId3(Long varietiesId3) {
        this.varietiesId3 = varietiesId3;
    }
    public String getVarietiesName3() {
        return varietiesName3;
    }

    public void setVarietiesName3(String varietiesName3) {
        this.varietiesName3 = varietiesName3;
    }
    public BigDecimal getThousandRate3() {
        return thousandRate3;
    }

    public void setThousandRate3(BigDecimal thousandRate3) {
        this.thousandRate3 = thousandRate3;
    }
    @ReferSerialTransfer(referCode="ProductRef")
    public Long getProductId() {
        return productId;
    }

    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }
    
}
